import 'package:flutter/material.dart';
import 'package:geideadesignframework/style_config.dart';

import 'style_config.dart';

class GeideaPrimaryButton extends StatefulWidget {
  GeideaPrimaryButton(
      {Key key,
      @required this.text,
      @required this.clickCallback,
      this.isDisabled = false,
      this.preTextWidget,
      this.postTextWidget,
      this.textColor,
      this.backgroundColor,
      this.disabledColor,
      this.borderRadius,
      this.fontSize,
      this.borderWidth,
      this.padding,
      this.letterSpacing,
      this.fontWeight})
      : super(key: key);

  final String text;
  final bool isDisabled;
  final VoidCallback clickCallback;
  final Widget preTextWidget;
  final Widget postTextWidget;
  final Color textColor;
  final Color backgroundColor;
  final Color disabledColor;
  final double borderRadius;
  final double fontSize;
  final double borderWidth;
  final double letterSpacing;
  final EdgeInsets padding;
  final FontWeight fontWeight;

  @override
  _GeideaPrimaryButtonState createState() => _GeideaPrimaryButtonState();
}

class _GeideaPrimaryButtonState extends State<GeideaPrimaryButton> {
  bool _isButtonDisabled;

  @override
  void initState() {
    _isButtonDisabled = _isButtonDisabled;
  }

  void _disableButton() {
    setState(() {
      _isButtonDisabled = true;
    });
  }

  @override
  Widget build(BuildContext context) {
    return IgnorePointer(
      ignoring: _isButtonDisabled,
      child: RawMaterialButton(
          onPressed: () {
            if (!_isButtonDisabled) widget.clickCallback();
          },
          padding: widget.padding ?? styleConfig.mainButtonPadding,
          shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(
                  widget.borderRadius ?? styleConfig.borderRadius)),
          elevation: 0,
          disabledElevation: 0,
          fillColor: _isButtonDisabled
              ? (widget.backgroundColor != null ? widget.backgroundColor.withAlpha(77) :
                  styleConfig.theme.primaryColor.withAlpha(77))
              : (widget.backgroundColor ?? styleConfig.theme.primaryColor),
          highlightColor: widget.backgroundColor != null ?  widget.backgroundColor.withOpacity(0.3) :
              styleConfig.theme.primaryColor.withOpacity(0.3),
          child: Row(mainAxisAlignment: MainAxisAlignment.center, children: <
              Widget>[
            widget.preTextWidget == null ? Container() : widget.preTextWidget,
            Text(
              widget.text,
              style: TextStyle(
                fontFamily: styleConfig.fontFamily,
                fontSize: widget.fontSize ?? styleConfig.getFontSize('button'),
                fontWeight:
                    widget.fontWeight ?? styleConfig.mainButtonFontWeight,
                letterSpacing:
                    widget.letterSpacing ?? styleConfig.letterSpacing,
                color: widget.textColor ?? styleConfig.theme.canvasColor,
              ),
            ),
            widget.postTextWidget == null ? Container() : widget.postTextWidget,
          ])),
    );
  }
}
