import 'package:flutter/material.dart';

final StyleConfig styleConfig = new StyleConfig._();

///Singleton
class StyleConfig {
  StyleConfig._();

  ///Should have our predefined colors
  ThemeData _theme = new ThemeData(
    primaryColor: Color(0xffFF4D00),
    accentColor: Color(0xff343F4B),
    cursorColor: Color(0xff4285f4),
    primaryColorLight: Color(0xffFFBE9F),
    primaryColorDark: Color(0xffe64a19),
    dividerColor: Color(0x1f343F4B),
    toggleableActiveColor: Color(0xfff4511e),
    secondaryHeaderColor: Color(0xfffbe9e7),
    textSelectionColor: Color(0xffffab91),
    errorColor: Color(0xffd32f2f),
    canvasColor: Color(0xfffafafa),
    bottomAppBarColor: Color(0xffffffff),
    cardColor: Color(0xffffffff),
    highlightColor: Color(0x66bcbcbc),
    splashColor: Color(0x66c8c8c8),
    unselectedWidgetColor: Color(0x8a343F4B),
    disabledColor: Color(0x61343F4B),
    buttonColor: Color(0xffFF4D00),
  );

  EdgeInsets _padding = EdgeInsets.symmetric(vertical: 10.0);
  double _paddingVertical = 10.0;
  double _paddingHorizontal = 10.0;
  double _mainFontSize = 14.0;
  double _mainButtonFontSize = 16.0;
  double _letterSpacing = 0.5;
  double _borderRadius = 18.0;
  double _borderWidth = 1.0;
  double _iconSize = 20.0;
  FontWeight _mainButtonFontWeight = FontWeight.normal;
  EdgeInsets _mainButtonPadding = EdgeInsets.symmetric(horizontal: 38.0, vertical: 12.0);

  

  String _fontFamily = 'Montserrat';
  String _secondaryFontFamily = 'Montserrat';

/*  BaseColors currentColors = BaseColors(
  );
  */

  //setters
  void setBaseTheme(ThemeData theme) {
    _theme = theme;
  }

  void setPadding(EdgeInsets padding) {
    _padding = padding;
  }

  void setLetterSpacing(double letterSpacing) {
    _letterSpacing = letterSpacing;
  }

  void setMainFontSize(double mainFontSize) {
    _mainFontSize = mainFontSize;
  }

  void setBorderRadius(double borderRadius) {
    _borderRadius = borderRadius;
  }

  void setBorderWidth(double borderWidth) {
    _borderWidth = borderWidth;
  }
  void setPaddingVertical(double paddingVertical) {
    _paddingVertical = paddingVertical;
  }
  void setPaddingHorizontal(double paddingHorizontal) {
    _paddingHorizontal = paddingHorizontal;
  }

  void setIconSize(double iconSize) {
    _iconSize = iconSize;
  }

  void setFontFamily(String fontFamily) {
    _fontFamily = fontFamily;
  }

  void setSecondaryFontFamily(String fontFamily) {
    _secondaryFontFamily = fontFamily;
  }

  void setMainButtonFontWeight(FontWeight fontWeight) {
    _mainButtonFontWeight = fontWeight;
  }
  void setMainButtonPadding(EdgeInsets padding) {
    _mainButtonPadding = padding;
  }
  //getters
  ThemeData get theme {
    return _theme;
  }

  EdgeInsets get padding {
    return _padding;
  }

  double get mainFontSize {
    return _mainFontSize;
  }

  double get letterSpacing {
    return _letterSpacing;
  }

  double get borderRadius {
    return _borderRadius;
  }

  double get borderWidth {
    return _borderWidth;
  }
  double get paddingVertical {
    return _paddingVertical;
  }
  double get paddingHorizontal {
    return _paddingHorizontal;
  }

  double get iconSize {
    return _iconSize;
  }

  String get fontFamily {
    return _fontFamily;
  }

  String get secondaryFontFamily {
    return _secondaryFontFamily;
  }

  FontWeight get mainButtonFontWeight {
    return _mainButtonFontWeight;
  }
  EdgeInsets get mainButtonPadding {
    return _mainButtonPadding;
  }

  Map<String, double> _fontSizes = {
    'headline1 ': 96.0,
    'headline2': 60.0,
    'headline3': 48.0,
    'headline4': 34.0,
    'headline5': 24.0,
    'headline6': 20.0,
    'subtitle1': 16.0,
    'subtitle2': 14.0,
    'body1': 16.0,
    'body2': 14.0,
    'button': 16.0,
    'caption': 12.0,
    'overline': 10.0,
  };

  void setFontSizes(Map<String, double> fontSizes) {
    _fontSizes.addAll(fontSizes);
  }

  Map<String, double> get fontSizes {
    return _fontSizes;
  }

  double getFontSize(String fontSizeName) {
    return _fontSizes[fontSizeName];
  }
}
